@@ -194,17 +194,20 @@ def main(argv):
                 print('python -m artify -c create -f <template_file>')
                 print("Mandatory argument(s): ")
                 print('-f, --file    Template file to create e.g manifest, gitlabci')
+                return sys.exit(0)
             elif arg == 'extract':
                 print('')
                 print('python -m artify -c extract \n')
                 print('Sample commit messages below: \n')
                 print("Added login functionality {\"version\": \"patch\", \"archtype\": \"npm\", \"branch\": \"release\" } \n")
                 print("Added edit functionality {\"version\": \"minor\", \"a\": \"flutter\" } \n")
+                return sys.exit(0)
             elif arg == 'initialize':
                 print('')
                 print('python -m artify -c initialize -h <SonarQube_base_url> -u <username> -p <password> -a <arch_type/os> -l <language>')    
-                print('\nExample below for a java project that uses gradle build tool.')
+                print('\nExample command below for a java project that uses gradle build tool.')
                 print('\npython -m artify -c initialize -h <SonarQube_base_url> -u <username> -p <password> -l java -a gradle\n')
+                return sys.exit(0)
             else:
                 print('python -m artify --help nexus        Help on how to deploy to Nexus Repository')
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
