@@ -52,7 +52,7 @@ def commit_push_changes(message):
         print("INFO: Commit result: ", process_git_commit.communicate()[0])
     
     if __main__.os.environ.get('PRIVATE_TOKEN') == None:
-        print("ERROR: Private token missing. Please added PRIVATE_TOKEN to Environment variables")
+        print("ERROR: Private token missing. Please add PRIVATE_TOKEN to Environment variables")
         __main__.os.sys.exit(1)
     
     auth = "//" + __main__.os.environ.get('GITLAB_USER_LOGIN') + ":" + __main__.os.environ.get('PRIVATE_TOKEN') + "@"
@@ -69,7 +69,7 @@ def commit_push_changes(message):
     if __main__.branch == '' and message == 'tag':
         __main__.branch = 'master'
       
-    print("INFO: Pushing version changes:::")
+
     ##git_push_command = "git push origin {}".format(os.environ.get('CI_COMMIT_BRANCH'))
     
     # To-do Delete branch after merge with feature/patch-version, feature/minor-version, feature/major-version, feature/release-version
@@ -80,8 +80,10 @@ def commit_push_changes(message):
     # git push origin --delete remoteBranchName
     
     if message == 'tag':
+        print("INFO: Pushing tags to repository:::")
         git_push_command = "git config user.name {}; git config user.email {}; git push --tags {} HEAD:{}".format(__main__.os.environ.get('GITLAB_USER_LOGIN'), __main__.os.environ.get('GITLAB_USER_EMAIL'), ci_repo_url, __main__.branch)
     else: 
+        print("INFO: Pushing version changes:::")
         git_push_command = "git config user.name {}; git config user.email {}; git push {} HEAD:{}".format(__main__.os.environ.get('GITLAB_USER_LOGIN'), __main__.os.environ.get('GITLAB_USER_EMAIL'), ci_repo_url, __main__.branch)
  
     ##git_push_command = "git config user.name {}; git config user.email {}; git push {} HEAD:{}".format(os.environ.get('GITLAB_USER_LOGIN'), os.environ.get('GITLAB_USER_EMAIL'), ci_repo_url, os.environ.get('CI_COMMIT_BRANCH'))
